@@ -86,7 +86,7 @@
 #define PLASMA_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PLASMA_NO_DEPRECATED
-#  define PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55100
+#  define PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef PLASMA_NO_DEPRECATED_WARNINGS
 #  define PLASMA_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PLASMA_DEPRECATED_WARNINGS_SINCE PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PLASMA_DEPRECATED_WARNINGS_SINCE 0x55100
+#    define PLASMA_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -172,5 +172,12 @@
 #define PLASMA_DEPRECATED_VERSION_5(minor, text)      PLASMA_DEPRECATED_VERSION_5_##minor(text)
 #define PLASMA_DEPRECATED_VERSION(major, minor, text) PLASMA_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define PLASMA_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) PLASMA_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define PLASMA_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) PLASMA_DEPRECATED_VERSION(major, minor, text)
+#  define PLASMA_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) PLASMA_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define PLASMA_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define PLASMA_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* PLASMA_EXPORT_H */
