@@ -86,7 +86,7 @@
 #define PLASMAQUICK_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PLASMAQUICK_NO_DEPRECATED
-#  define PLASMAQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55000
+#  define PLASMAQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef PLASMAQUICK_NO_DEPRECATED_WARNINGS
 #  define PLASMAQUICK_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef PLASMAQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PLASMAQUICK_DEPRECATED_WARNINGS_SINCE PLASMAQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PLASMAQUICK_DEPRECATED_WARNINGS_SINCE 0x55000
+#    define PLASMAQUICK_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -130,5 +130,12 @@
 #define PLASMAQUICK_DEPRECATED_VERSION_5(minor, text)      PLASMAQUICK_DEPRECATED_VERSION_5_##minor(text)
 #define PLASMAQUICK_DEPRECATED_VERSION(major, minor, text) PLASMAQUICK_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define PLASMAQUICK_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) PLASMAQUICK_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define PLASMAQUICK_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) PLASMAQUICK_DEPRECATED_VERSION(major, minor, text)
+#  define PLASMAQUICK_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) PLASMAQUICK_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define PLASMAQUICK_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define PLASMAQUICK_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* PLASMAQUICK_EXPORT_H */
